using System;
using System.Collections.Generic;
using System.Collections;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using UnityEngine;
using Unity;

namespace Mod
{

    public class Mod
    {
        public static AudioClip clip;
        public static void Main()
        {
            ModAPI.RegisterLiquid(ZombieMaxeLiquid.ID, new ZombieMaxeLiquid());
            ModAPI.RegisterLiquid(AntidotZombie.ID, new AntidotZombie());
            clip = ModAPI.LoadSound("syringe.mp3");
            ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Knife"),
                     NameOverride = "Advanced zombie injector",
                     DescriptionOverride = "You have some little time to get rid of injected limb, before a human being turns into a zombie. \n <b> NOTE: Do not inject in bodyparts like: Chest, Head, as it can be lethal for your human</b>",
                     CategoryOverride = ModAPI.FindCategory("Chemistry"),
                     ThumbnailOverride = ModAPI.LoadSprite("thumbo.png"),
                     NameToOrderByOverride = "AZI1",
                     AfterSpawn = (Instance) =>
                     {
                         Instance.AddComponent<Connector>();
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Injector.png");
                     }
                 }
             );
            ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Knife"),
                     NameOverride = "Instant advanced zombie injector",
                     DescriptionOverride = "Virus cells take over of human's body instantly. Human turns just as the injector is stabbed. \n <b> NOTE: Do not inject in bodyparts like: Chest, Head, as it can be lethal for your human</b>",
                     CategoryOverride = ModAPI.FindCategory("Chemistry"),
                     ThumbnailOverride = ModAPI.LoadSprite("Thumbo3.png"),
                     NameToOrderByOverride = "AZI2",
                     AfterSpawn = (Instance) =>
                     {
                         Instance.AddComponent<InstantVirus>();
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("MomentalZombie.png");
                     }
                 }
             );
            ModAPI.Register(
                 new Modification()
                 {
                     OriginalItem = ModAPI.FindSpawnable("Knife"),
                     NameOverride = "Antidot",
                     DescriptionOverride = "Kills zombie virus cells, brings human back from it's disease.",
                     CategoryOverride = ModAPI.FindCategory("Chemistry"),
                     ThumbnailOverride = ModAPI.LoadSprite("Thumbo (2).png"),
                     NameToOrderByOverride = "AZI3",
                     AfterSpawn = (Instance) =>
                     {
                         Instance.AddComponent<Antidot>();
                         Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("Immune.png");
                     }
                 }
             );
        }

    }
    public class Antidot : MonoBehaviour
    {
        void Lodged(Stabbing stabbing)
        {
            var limb = stabbing.victim.gameObject.GetComponent<LimbBehaviour>();
            limb.CirculationBehaviour.AddLiquid(Liquid.GetLiquid("ANTIDOT UNICAL"), 10f);
        }
        void Dislodged(PhysicalBehaviour.Penetration penetration)
        {
            var limb = penetration.Victim.gameObject.GetComponent<LimbBehaviour>();
            limb.CirculationBehaviour.AddLiquid(Liquid.GetLiquid("ANTIDOT UNICAL"), 10f);
            limb.CirculationBehaviour.AddLiquid(Liquid.GetLiquid("MENDING SERUM"), 10f);
        }
    }
    public class Connector : MonoBehaviour
    {
        private bool beenActivated = false;
        void Lodged(Stabbing stabbing)
        {
            try
            {
                if (!beenActivated && stabbing.victim.gameObject.GetComponent<LimbBehaviour>() != null)
                {
                    var limb = stabbing.victim.gameObject.GetComponent<LimbBehaviour>();
                    limb.CirculationBehaviour.HealBleeding();
                    StartCoroutine(Infect(limb));
                    gameObject.GetComponent<AudioSource>().clip = Mod.clip;
                    gameObject.GetComponent<AudioSource>().Play();
                    limb.CirculationBehaviour.Unstabbed(stabbing);
                }
            }
            catch
            {

            }
        }
        void Dislodged(PhysicalBehaviour.Penetration penetration)
        {
            try
            {
                if (!beenActivated)
                {
                    var limb = penetration.Victim.gameObject.GetComponent<LimbBehaviour>();
                    limb.CirculationBehaviour.AddLiquid(Liquid.GetLiquid("MENDING SERUM"), 10f);
                    beenActivated = true;
                    StartCoroutine(Infect(limb));
                }
            }
            catch
            {

            }
        }
        IEnumerator Infect(LimbBehaviour limb)
        {
            yield return new WaitForSeconds(UnityEngine.Random.Range(21f, 33f));
            if (!limb.IsDismembered)
            {
                limb.CirculationBehaviour.HealBleeding();
                limb.CirculationBehaviour.AddLiquid(Liquid.GetLiquid("ZOMBIE UNICAL"), 10f);
            }
        }
    }
    public class InstantVirus : MonoBehaviour
    {
        private bool beenActivated = false;
        void Lodged(Stabbing stabbing)
        {
            try
            {
                if (!beenActivated && stabbing.victim.gameObject.GetComponent<LimbBehaviour>() != null)
                {
                    var limb = stabbing.victim.gameObject.GetComponent<LimbBehaviour>();
                    limb.CirculationBehaviour.HealBleeding();
                    limb.CirculationBehaviour.AddLiquid(Liquid.GetLiquid("ZOMBIE UNICAL"), 10f);
                    gameObject.GetComponent<AudioSource>().clip = Mod.clip;
                    gameObject.GetComponent<AudioSource>().Play();

                }
            }
            catch
            {

            }
        }

        IEnumerator Infect(LimbBehaviour limb)
        {
            yield return new WaitForSeconds(UnityEngine.Random.Range(21f, 33f));
            if (!limb.IsDismembered)
            {
                limb.CirculationBehaviour.HealBleeding();
                limb.CirculationBehaviour.AddLiquid(Liquid.GetLiquid("ZOMBIE UNICAL"), 10f);
            }
        }
    }
    public class ZombieMaxeLiquid : Liquid
    {
        // Token: 0x060015E5 RID: 5605 RVA: 0x00064E89 File Offset: 0x00063089
        public ZombieMaxeLiquid()
        {
            this.Color = new Color(0.8835177f, 1f, 0.7122642f);
        }

        // Token: 0x060015E6 RID: 5606 RVA: 0x00064EAB File Offset: 0x000630AB
        public override void OnEnterContainer(BloodContainer container)
        {
        }

        // Token: 0x060015E7 RID: 5607 RVA: 0x00064EB0 File Offset: 0x000630B0
        public override void OnEnterLimb(LimbBehaviour limb)
        {
            if (limb.SpeciesIdentity == "Android")
            {
                return;
            }
            limb.IsZombie = true;

            limb.Health = limb.InitialHealth;
            limb.Numbness = 0f;
            CirculationBehaviour circulationBehaviour = limb.CirculationBehaviour;
            float amount = circulationBehaviour.GetAmount(limb.GetOriginalBloodType());
            if (amount < 0.1f)
            {
                circulationBehaviour.AddLiquid(limb.GetOriginalBloodType(), 1f - amount);
            }
            circulationBehaviour.BloodFlow = 1f;
            circulationBehaviour.HealBleeding();
            circulationBehaviour.BleedingRate = 0f;
            circulationBehaviour.IsPump = circulationBehaviour.WasInitiallyPumping;
            limb.BreakingThreshold += 10f;
            limb.HealBone();
            limb.Health = limb.InitialHealth;
            if (limb.RoughClassification == LimbBehaviour.BodyPart.Head)
            {
                limb.Person.Consciousness = 1f;
                limb.Person.ShockLevel = 0f;
                limb.Person.PainLevel = 0f;
                limb.Person.OxygenLevel = 1f;
                limb.Person.AdrenalineLevel = 1f;

                if (limb.gameObject.GetComponent<Bite>() == null)
                {
                    limb.gameObject.AddComponent<Bite>();
                }
            }
        }

        // Token: 0x060015E8 RID: 5608 RVA: 0x00064F9E File Offset: 0x0006319E
        public override void OnExitContainer(BloodContainer container)
        {
        }

        // Token: 0x04001389 RID: 5001
        public const string ID = "ZOMBIE UNICAL";
    }
    public class AntidotZombie : Liquid
    {
        // Token: 0x060015E5 RID: 5605 RVA: 0x00064E89 File Offset: 0x00063089
        public AntidotZombie()
        {
            this.Color = Color.black;
        }

        // Token: 0x060015E6 RID: 5606 RVA: 0x00064EAB File Offset: 0x000630AB
        public override void OnEnterContainer(BloodContainer container)
        {
        }

        // Token: 0x060015E7 RID: 5607 RVA: 0x00064EB0 File Offset: 0x000630B0
        public override void OnEnterLimb(LimbBehaviour limb)
        {
            if (limb.SpeciesIdentity == "Android")
            {
                return;
            }
            limb.CirculationBehaviour.RemoveLiquid(Liquid.GetLiquid("ZOMBIE UNICAL"), limb.CirculationBehaviour.GetAmount(Liquid.GetLiquid("ZOMBIE UNICAL")));
            limb.IsZombie = false;
            limb.CirculationBehaviour.AddLiquid(Liquid.GetLiquid("MENDING SERUM"), 10f);
            if (limb.RoughClassification == LimbBehaviour.BodyPart.Head)
            {
                var biteComp = limb.gameObject.GetComponent<Bite>();
                UnityEngine.Object.Destroy(biteComp);
            }
        }

        // Token: 0x060015E8 RID: 5608 RVA: 0x00064F9E File Offset: 0x0006319E
        public override void OnExitContainer(BloodContainer container)
        {
        }

        // Token: 0x04001389 RID: 5001
        public const string ID = "ANTIDOT UNICAL";
    }
    public class Bite : MonoBehaviour
    {
        private bool Recoil = true;
        void OnCollisionEnter2D(Collision2D collision)
        {
            if (collision.gameObject.GetComponent<LimbBehaviour>() != null && !gameObject.GetComponent<LimbBehaviour>().Person.Braindead)
            {
                if (collision.gameObject.GetComponent<LimbBehaviour>().CirculationBehaviour.GetAmount(Liquid.GetLiquid("ZOMBIE UNICAL")) == 0 && Recoil == true)
                {
                    StartCoroutine(Infect(collision.gameObject.GetComponent<LimbBehaviour>()));
                    collision.gameObject.GetComponent<LimbBehaviour>().SkinMaterialHandler.AddDamagePoint(DamageType.Stab, collision.contacts[0].point, 15f);
                    collision.gameObject.AddComponent<AudioSource>().PlayOneShot(collision.gameObject.GetComponent<LimbBehaviour>().PhysicalBehaviour.Properties.StabSound.PickRandom<AudioClip>(), 0.6f);
                    Recoil = false;
                    StartCoroutine(Timer(UnityEngine.Random.Range(3f, 6f)));
                }
            }
        }
        IEnumerator Timer(float seconds)
        {
            yield return new WaitForSeconds(seconds);
            Recoil = true;
        }
        IEnumerator Infect(LimbBehaviour limb)
        {
            yield return new WaitForSeconds(UnityEngine.Random.Range(21f, 33f));
            if (!limb.IsDismembered)
            {
                limb.CirculationBehaviour.AddLiquid(Liquid.GetLiquid("ZOMBIE UNICAL"), 10f);
            }
        }
    }
}